@@ -127,12 +127,11 @@ rmw_do_all <- function(df, variables, variables_sample = NA, n_trees = 300,
   date_post_normalise <- as.numeric(lubridate::now())
   
   # Build timing data frame
-  df_times <- data.frame(
+  df_times <- data_frame(
     hostname = as.character(Sys.info()["nodename"]),
     date_start,
     date_post_training,
-    date_post_normalise,
-    stringsAsFactors = FALSE
+    date_post_normalise
   ) %>% 
     mutate(time_elasped_training = date_post_training - date_start,
            time_elapsed_normalising = date_post_normalise - date_post_training,
