@@ -13,7 +13,7 @@ test_that("Test data preparation function", {
   df <- rmw_prepare_data(df)
   
   # Test data frame
-  expect_identical(class(df), "data.frame")
+  expect_identical(class(df), c("tbl_df", "tbl", "data.frame"))
   expect_identical(ncol(df), 16L)
   expect_identical(class(df$date)[1], "POSIXct")
   
@@ -31,12 +31,12 @@ test_that("Test data preparation function with custom arguments", {
   
   expect_identical(
     class(rmw_prepare_data(data_london, value = "nox", na.rm = TRUE)), 
-    "data.frame"
+    c("tbl_df", "tbl", "data.frame")
   )
   
   expect_identical(
     class(rmw_prepare_data(data_london, value = "nox", replace = TRUE)), 
-    "data.frame"
+    c("tbl_df", "tbl", "data.frame")
   )
   
 })
@@ -65,15 +65,15 @@ test_that("Test training function", {
   
   # Test model return
   expect_identical(class(model), "ranger")
-  expect_equal(model$r.squared, 0.4184627, tolerance = 0.1)
+  expect_equal(model$r.squared, 0.4184627, tolerance = 0.2)
   
   # Extract things from model
   df_importance <- rmw_model_importance(model)
   df_performance <- rmw_model_statistics(model)
   
   # 
-  expect_identical(class(df_importance), "data.frame")
-  expect_identical(class(df_performance), "data.frame")
+  expect_identical(class(df_importance), c("tbl_df", "tbl", "data.frame"))
+  expect_identical(class(df_performance), c("tbl_df", "tbl", "data.frame"))
   
   # Plot
   expect_identical(class(rmw_plot_importance(df_importance)), c("gg", "ggplot"))
@@ -82,7 +82,7 @@ test_that("Test training function", {
   df_predict <- rmw_predict_the_test_set(model = model, df = df)
   plot_test <- rmw_plot_test_prediction(df_predict)
   
-  expect_identical(class(df_predict), "data.frame")
+  expect_identical(class(df_predict), c("tbl_df", "tbl", "data.frame"))
   expect_identical(class(plot_test), c("gg", "ggplot"))
   
   # Is this needed? 
@@ -124,7 +124,7 @@ test_that("Test normalising function", {
   )
   
   # Check 
-  expect_identical(class(df_normalise), "data.frame")
+  expect_identical(class(df_normalise), c("tbl_df", "tbl", "data.frame"))
   expect_identical(names(df_normalise), c("date", "value_predict"))
   expect_identical(class(df$date)[1], "POSIXct")
   
@@ -165,8 +165,8 @@ test_that("Test normalising function with standard error calculation", {
   )
   
   # Check 
-  expect_identical(class(df_normalise), "data.frame")
-  expect_identical(names(df_normalise), c("date", "value_predict", "se"))
+  expect_identical(class(df_normalise), c("tbl_df", "tbl", "data.frame"))
+  expect_identical(names(df_normalise), c("date", "se", "value_predict"))
   expect_identical(class(df$date)[1], "POSIXct")
   
 })
@@ -198,9 +198,13 @@ test_that("Test `rmw_do_all` function", {
   expect_identical(class(list_normalised), "list")
   
   # Check types
+  list_types <- purrr::map(list_normalised, class) %>% 
+    purrr::map_chr(`[[`, 1) %>% 
+    unname()
+  
   expect_identical(
-    unname(purrr::map_chr(list_normalised, class)),
-    c("data.frame", "ranger", "integer", "data.frame", "data.frame")
+    list_types,
+    c("tbl_df", "ranger", "integer", "tbl_df", "tbl_df")
   )
   
 })
@@ -238,9 +242,13 @@ test_that("Test `rmw_do_all` function and use varable_sample argument", {
   expect_identical(class(list_normalised), "list")
   
   # Check types
+  list_types <- purrr::map(list_normalised, class) %>% 
+    purrr::map_chr(`[[`, 1) %>% 
+    unname()
+  
   expect_identical(
-    unname(purrr::map_chr(list_normalised, class)),
-    c("data.frame", "ranger", "integer", "data.frame", "data.frame")
+    list_types,
+    c("tbl_df", "ranger", "integer", "tbl_df", "tbl_df")
   )
   
 })
@@ -272,6 +280,6 @@ test_that("Test `rmw_clip` function", {
   df <- rmw_clip(list_normalised$normalised)
   
   # Check
-  expect_identical(class(df), "data.frame")
+  expect_identical(class(df), c("tbl_df", "tbl", "data.frame"))
   
 })
